玩具总动员3 (豆瓣)
Description: 玩具总动员3电影简介和剧情介绍,玩具总动员3影评、图片、预告片、影讯、论坛、在线购票
Keywords: 玩具总动员3,Toy Story 3,玩具总动员3影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.137豆瓣电影Top250

# 玩具总动员3 Toy Story 3 (2010)

导演: 李·昂克里奇
编剧: 迈克尔·阿恩特 / 约翰·拉塞特 / 安德鲁·斯坦顿 / 李·昂克里奇
主演: 汤姆·汉克斯 / 蒂姆·艾伦 / 琼·库萨克 / 尼德·巴蒂 / 唐·里克斯 / 迈克尔·基顿
类型: 喜剧 / 动画 / 奇幻 / 冒险
官方网站: http://disney.go.com/toystory/
制片国家/地区: 美国
语言: 英语 / 西班牙语
上映日期: 2010-06-16(中国大陆) / 2010-06-18(美国)
片长: 103分钟
又名: 反斗奇兵3(港) / 玩具的故事3
IMDb: tt0435761
豆瓣评分
引用
8.9
486184人评价
5星
54.5%
4星
36.0%
3星
9.0%
2星
0.4%
1星
0.1%
好于 98% 动画片
好于 99% 喜剧片
想看 看过
评价:
推荐

## 玩具总动员3的剧情简介 · · · · · ·

距上一次的冒险已经过去11个年头，转眼间安迪（约翰·莫里斯 John Morris 配音）变成了17岁的阳光男孩。这年夏天，安迪即将开始大学生活，他必须将自己的房间收拾整齐留给妹妹。此前，伍迪（汤姆·汉克斯 Tom Hanks 配音）与巴斯光年（蒂姆·艾伦 Tim Allen 配音）等玩具一直期待安迪再和他们玩耍，但是随着岁月的流逝，他们被冷落在箱子里很久了。安迪十分珍惜这些童年的玩伴，于是准备将他们收在阁楼。谁曾想，妈妈却把玩具们当作废物扔到街道上。玩具们误解了安迪，于是愤然出走，宁可被捐赠到阳光之家幼儿园。
伍迪尽力劝解大家，却收效甚微，只得独自黯然离开。巴斯光年他们原本以为将重新回到往昔的快乐时光，不料却陷入一场阴谋之中…… ©豆瓣

## 玩具总动员3的演职员 · · · · · · ( 全部 42 )

- 李·昂克里奇 导演
- 汤姆·汉克斯 配音
- 蒂姆·艾伦 配音
- 琼·库萨克 配音
- 尼德·巴蒂 配音
- 唐·里克斯 配音

## 玩具总动员3的视频和图片 · · · · · · ( 预告片2 | 添加视频评论 | 图片1292 · 添加 )

## 玩具总动员3的获奖情况 · · · · · · ( 全部 )

- 第83届奥斯卡金像奖
- 最佳影片(提名)
- 达拉·K·安德森

- 第68届金球奖
- 电影类 最佳动画长片

- 第34届日本电影学院奖
- 最佳外语片(提名)

## 喜欢这部电影的人也喜欢 · · · · · ·

  玩具总动员2

  大闹天宫

  怪兽电力公司

  天空之城

  哪吒闹海

  幽灵公主

  赛车总动员

  冰川时代

  哈尔的移动城堡

  美食总动员

我要写短评

## 玩具总动员3的短评 · · · · · · ( 全部 85028 条 )

热门 / 最新 / 好友

### 3335 有用 猪是的念来过倒 看过 2010-06-16 22:12:00

我87年出生，，看toy 1是小学3年级。看toy3是大学毕业。纯爷们，没哭死我。。。。我想说 这是皮克斯送给我们这代人的一份礼物。再见了，我的童年，谢谢你，皮克斯

### 128 有用 辣辣的皮特 看过 2010-06-16 12:02:25

感觉很平淡呀，难道童心离我而去了吗？no...另外，3D效果不如驯龙高手。

### 2302 有用 ｄａｂａｉ 看过 2010-06-16 02:00:01

玩具总动员3的感人之处就是帮我们这些老家伙给了一个正式的和童年say goodbye的机会，当上大学的andy再一次背起woody的时候，十五年的光阴就这么友好又温柔地消失在木栅屋远处的夕阳中了。

### 1575 有用 影子的影子 看过 2010-06-11 06:36:18

前半部分就有好几次想哭的冲动，本来以为这次能够幸免的，没想到最后几分钟那么煽情，简直要哭死了。其实3D效果并没有很出色，但是精彩的剧本真的很让人感动。这不是一部给小孩子的动画，是一部给成人的童话。

### 1300 有用 山人阿苍苍 看过 2010-06-12 19:56:06

让我笑已经够了，居然还能让我哭，nice job！

> 更多短评 85028条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 玩具总动员3的影评 · · · · · · ( 全部 1137 条 )

热门 / 最新 / 好友
锡罐头 2010-06-16 18:13:41

## 一场完美的道别

这篇影评可能有剧透

作为一部经典电影的续集，往往是不讨好的，通常都被冠以“狗尾续貂”抢钱之嫌，所以当皮克斯决定重拾十年前落下的“玩具系列”，估计这块金字招牌也让不少人捏了把汗。而当我看完这部影片，心里剩下的，只有满满的感动和惊喜。 本片相距上一部也十年有余，于是皮克斯... (展开)
2639 35 298回应 收起
Pearciac 2010-06-16 22:53:40

## 再见，玩具们

这篇影评可能有剧透

这是一个哀伤的故事。即使里面点缀着各式的笑点，各种童年的欢乐景象和“大家在一起”的温馨场面，甚至“越狱”这样喜感的重头戏码，也无法掩住那一丝丝的惆怅气息。好似一杯红酒加了再多的糖，回味起来也还有涩味，决不会再成为葡萄汁。哀伤在Andy开车离开前那个纠结眼神，... (展开)
599 16 388回应 收起
麻绳 2010-06-13 11:55:39

## 《玩具总动员3》：一颗流弹打中我胸膛

皮克斯动画确实是出了名的慢工出细活，《玩具总动员3》距离第一部已经15年了，距离第二部也已经超过了10年，作为一部动画片来说，这样的时间跨度意味着最早通过第一部爱上伍迪和巴斯光年的那批小观众现在已经步入成年，其实这对一部儿童片的续集来说是很不利的局面。但好在皮... (展开)
441 29 113回应 收起
柏邦妮 2010-07-28 15:51:31

## 玩具总动员三与藤泽周平

上周看了《玩具总动员三》，觉得美国的动画片好厉害啊。 虽然是给孩子看的，但是抚慰的却是成年人。 在我看来，玩三是讲一个“不再有用，不再被需要”的人的故事： 曾经被需要，形影不离，但是如今已经好景不再， 是重新祈求对方的爱护，还是往前走？ 外面的世界纵然可怕，纵... (展开)
83 9 20回应 收起
TORO VAN DARKO 2010-07-16 07:45:20

## 一次情感宣泄

这篇影评可能有剧透

电影进行到快60分钟时，我以为自己已经失望了。从电影开场到越狱之前的段落，用了太多前作的套路。玩具因为被抛弃被替代的伤感情绪是第一部的中心，在第二部中也有被提到，这次在第三部的前半段中却再次被放在了重要位置；第二部中已经有了杵着锄头笑里藏刀的矿工老头，... (展开)
59 3 20回应 收起
84消毒液 2015-11-14 23:21:27

## 主人会换很多玩具，但对玩具来说，每个主人都意义非凡

这一部迎来了残酷的现实，安迪长大了，他不再需要玩具了，玩具们很寂寞，千方百计地想要主人来玩自己一次，却失败了。 这一部中的胡迪一直很清醒，最开始在大家都要留在幼儿园的时候，他选择去陪伴主人，他的驴子想要和他一起，他拒绝了，因为他虽然爱自己的主人，但是也深刻... (展开)
59 1 1回应 收起
青年人电影协会 2018-03-07 11:40:22

## 玩具的热情

距上一次的冒险已经过去11个年头，转眼间安迪（约翰·莫里斯 John Morris 配音）变成了17岁的阳光男孩。这年夏天，安迪即将开始大学生活，他必须将自己的房间收拾整齐留给妹妹。此前，伍迪（汤姆·汉克斯 Tom Hanks 配音）与巴斯光年（蒂姆·艾伦 Tim Allen 配音）等玩具一直期... (展开)
42 0回应 收起
小凡 2010-06-19 02:26:54

## Love Is Needing To Be Loved

（1.标题是我正好听到这歌随手写的..2.如果你智商不像我这么低其实剧不剧透无所谓..<---五五阿姨这是巧合-。-） 走出放映厅的时候我嘴里碎碎叨叨地骂着不放完字幕就掐掉的死电影院，右手拿着3D眼镜，左手捏着一把潮乎乎的纸巾。 当我中午搭上从学校进市区的地铁临时决定还是趁... (展开)
32 5 28回应 收起
甜 2018-06-22 22:57:04

## 玩具

“当我成为一个男人的时候，我就把幼稚的东西放了出来。” 玩具总动员3是一幅令人惊叹、充满魔力的画面，让人想起了塔尔苏斯的名言，但它的制造者从未忘记自己是孩子的感觉。皮克斯动画工作室继续他们近乎连续的动画杰作，带着色彩缤纷的情感回归到电影中最好的玩具盒中。 在故... (展开)
15 1 0回应 收起

> 更多影评 1137篇

添加新讨论

## 讨论区 · · · · · ·

戴口罩收垃圾那个孩子就是1里面邻居的小孩嘛 | 来自宝宝刘 | 7 回应 | 2022-11-22 14:55:21
牧羊女的英文名是什么呀？ | 来自Noir | 3 回应 | 2022-11-02 22:17:41
为什么导演没有为大熊改邪归正？？ | 来自Alright | 23 回应 | 2022-10-28 09:53:48
为什么喜欢草莓熊 | 来自派派汤汤 |  | 2022-10-16 21:35:01
说说大家最喜欢的角色 | 来自Vanessa | 31 回应 | 2022-09-29 23:57:36

> 去这部影片的讨论区（全部366条）

## 关于《玩具总动员3》的问题 · · · · · · ( 全部8个 )

- woody的帽子是谁捡回幼儿园的？ 1人回答
- 芭比是如何骗到巴斯光年的说明书的？ 0人回答

> 全部8个问题

## 在哪儿看这部电影 · · · · · ·

- 咪咕视频 VIP免费观看
- 腾讯视频 VIP免费观看
- 西瓜视频 VIP免费观看

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- 2011 豆瓣电影【口碑榜】 (影志)
- 【内牛满面】 (影志)
- 【豆瓣高分动画长片】 (影志)
- {北美电影票房总排行} (荔枝超人)
- 【爱看动画】 (影志)

## 谁在看这部电影 · · · · · ·

- 戒
  刚刚 看过
- whcwhcwhc
  2分钟前 看过
- 涂凌峰
  2分钟前 想看

830947人看过 / 130972人想看

订阅玩具总动员3的评论:
feed: rss 2.0